@@ -1,5 +1,5 @@
 bd.ME.optim.rho.all <-
-function (x,t,sampling,yule = FALSE,maxitk=5,init=c(-1),posdiv=FALSE)  {
+function (x,t,sampling,yule = FALSE,maxitk=5,init=c(-1),posdiv=FALSE,survival=1)  {
 	if (yule==TRUE) {
 		print("not implemented. ext>0 !")
 		} else {
@@ -15,7 +15,7 @@ function (x,t,sampling,yule = FALSE,maxitk=5,init=c(-1),posdiv=FALSE)  {
     		mu<- c(mu,mutemp)
    	     }
     	rho<-c(sampling,p[(2*help+1):length(p)])
-        out<- treemrcashifts(x,t,l,mu,rho,posdiv) 
+        out<- treemrcashifts(x,t,l,mu,rho,posdiv,survival) 
         out
     }
     numb<-length(t)
