@@ -1,8 +1,8 @@
 bd.MEyule.optim <-
-function (x,t,rho,maxitk=5,init=c(-1))  {
+function (x,t,rho,maxitk=5,init=c(-1),groups=0)  {
 	x<-sort(x)
     dev <- function(p) {
-        out<- treemrcashifts(x,t,p,p*0,rho)
+        out<- treemrcashifts(x,t,p,p*0,rho,groups)
         out
     }
     numb<-length(rho)
